use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.18

use Test::More 0.88;
use Test::EOL;

my @files = (
    'Build.PL',
    'COPYING',
    'Changes',
    'GPLv3',
    'META.json',
    'META.yml',
    'README',
    'lib/Software/License/AGPL_3/or_later.pm',
    'lib/Software/License/GPL_1/or_later.pm',
    'lib/Software/License/GPL_2/or_later.pm',
    'lib/Software/License/GPL_3/or_later.pm',
    'lib/Software/License/LGPL_2_1/or_later.pm',
    'lib/Software/License/LGPL_3_0/or_later.pm',
    'lib/Software/License/OrLaterPack.pod',
    'manifest.txt',
    't/00-compile.t',
    't/01-test.t',
    'xt/author/eol.t',
    'xt/author/no-tabs.t',
    'xt/release/cpan-changes.t',
    'xt/release/fixme.t',
    'xt/release/meta-json.t',
    'xt/release/minimum-version.t',
    'xt/release/mojibake.t',
    'xt/release/pod-syntax.t',
    'xt/release/test-version.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
